@@ -1,15 +1,13 @@
-# $Id: Logger.pm,v 1.6 2004/04/11 23:36:20 joern Exp $
+# $Id: Logger.pm,v 1.1 2001/12/15 00:21:22 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::Logger;
-use Locale::TextDomain qw (video.dvdrip);
 
 use Carp;
 use strict;
@@ -53,21 +51,4 @@ sub log {
 	1;
 }
 
-sub nuke {
-	my $self = shift;
-
-	my $text = $self->text_widget;
-	
-	my $length = -s $self->project->logfile;
-	
-	$text->set_point( 0 );
-	$text->forward_delete( $length );
-
-	unlink $self->project->logfile;
-	
-	$self->log (__"Logfile nuked.");
-	
-	1;
-}
-
 1;
